<?php

declare(strict_types=1);

namespace Bartlett\CompatInfoDb;

use PDO;

class DatabaseFactory
{
    private static $tempDir;
    private static $database = 'compatinfo.sqlite';

    public static function create(string $type)
    {
        switch ($type) {
            case 'sqlite':
                return static::createSqliteDb();

            default:
                throw new \LogicException('unknown database type ' . $type);
        }
    }

    public static function getDsn(string $type) : array
    {
        switch ($type) {
            case 'sqlite':
                return static::getSqliteDsn();

            default:
                throw new \LogicException('unknown database type ' . $type);
        }
    }

    private static function getSqliteDsn() : array
    {
        if (($db = getenv('BARTLETT_COMPATINFO_DB')) && file_exists($db)) {
            static::$tempDir = dirname($db);
        } else if (file_exists($db = '/usr/share/php-bartlett-php-compatinfo-db/' . static::$database)) {
            static::$tempDir = dirname($db);
        } else {
            static::$tempDir = dirname(dirname(dirname(__DIR__))) . '/data';
		}

        return [
            'driver' => 'pdo_sqlite',
            'url' => 'sqlite:' . static::$tempDir . '/' . static::$database,
            'host' => 'localhost',
            'port' => '',
            'user' => 'root',
            'password' => '',
        ];
    }

    private static function createSqliteDb() : PDO
    {
        $dbParams = self::getSqliteDsn();

        return new PDO($dbParams['url']);
    }
}
